package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`%0`!````Y",```````!``````````#`!`0``
M`````@```$``.``'`$``%@`5``8````%````0`````````!``````````$``
M````````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!````````R`$````````>`````````!X``````````0`````````!````
M!0```````````````````````````````````-"<````````T)P`````````
M``$```````$````&````(/L````````@^P$``````"#[`0``````6`4`````
M``#`%0```````````0```````@````8```!(^P```````$C[`0``````2/L!
M``````#``0```````,`!````````"`````````!1Y71D!@``````````````
M```````````````````````````````````````````0`````````%+E=&0$
M````(/L````````@^P$``````"#[`0``````X`0```````#@!`````````$`
M````````+VQI8B]L9"UM=7-L+7!O=V5R<&,V-&QE+G-O+C$````1````:```
M``(````'````FH4`"`E`!$E(CA1!BH0`Z`````!H````;````'````!Q````
M=@```'<```!X`````````'H``````````````'L```!\````?0``````````
M````:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E
M/RRR`8MOXD?&`;OCDGQ5PSS29Z_,9H@'<--#1=7L,V+;[7^IG)OAIP(*H^#[
M20```````````````````````````````````````````P`'`$@<````````
M`````````````````P`,`"#[`0````````````````"L`P```@`(`(Q;````
M``````````````"Y`P```@`(`(A;``````````````````#&`P```@`(`(1;
M``````````````````#3`P```@`(`(!;``````````````````#@`P```@`(
M`'A;``````````````````#M`P```@`(`/!;``````````````````#Z`P``
M`@`(`/1;```````````````````'!````@`(`'Q;```````````````````[
M!````@`(`)Q;``````````````````!(!````@`(`)A;````````````````
M``!5!````@`(`)!;``````````````````!B!````@`(`)1;````````````
M``````"6!````@`(`*!;``````````````````"C!````@`(`*1;````````
M``````````"P!````@`(`-A;``````````````````"]!````@`(`+Q;````
M``````````````#*!````@`(`+A;``````````````````#7!````@`(`,1;
M``````````````````#D!````@`(`,!;``````````````````#Q!````@`(
M`+1;```````````````````B!0```@`(`,A;```````````````````Y!0``
M`@`(`,Q;``````````````````!&!0```@`(`-!;``````````````````!3
M!0```@`(`-1;``````````````````!M!0```@`(`+!;````````````````
M``"@!0```@`(`'1;```````````````````,````$@``````````````````
M``````#3`0``$@`````````````````````````4````$0``````````````
M``````````#Y`0``$0````````````````````````!U`0``$@``````````
M```````````````;````$@````````````````````````"R`0``$@``````
M```````````````````C````$@`````````````````````````&`@``$@``
M``````````````````````"^`0``$@`````````````````````````J````
M(`````````````````````````!)`P``(0````````````````````````!"
M````$@````````````````````````!(````$@``````````````````````
M``!/````$@`````````````````````````6`P``$@``````````````````
M```````'`P``$@````````````````````````"+`@``$@``````````````
M``````````!6````$@`````````````````````````L`@``$@``````````
M``````````````!=````$@````````````````````````#``@``$@``````
M``````````````````!D````$@````````````````````````!L````(```
M``````````````````````"`````$@````````````````````````"I`@``
M$@````````````````````````"(````$@````````````````````````".
M````$@````````````````````````"7````(```````````````````````
M`````P``$@````````````````````````"S````$@``````````````````
M``````"X````$@`````````````````````````7`@``$0``````````````
M``````````#'`@``$@````````````````````````!9`@``$@``````````
M``````````````"_````$@````````````````````````!+`@``$@``````
M``````````````````"C`P``$@````````````````````````#2`@``$0``
M``````````````````````!(`P``$0````````````````````````!]`@``
M$@`````````````````````````U`P``$@````````````````````````!*
M`P``$0````````````````````````#&````$@``````````````````````
M```M`P``$@````````````````````````"#`0``$@``````````````````
M``````#/````(@````````````````````````#>````(```````````````
M``````````#T````$@````````````````````````#X`@``$@``````````
M``````````````!I`@``$@````````````````````````#Y````$@``````
M``````````````````#_````(`````````````````````````"T`@``$@``
M```````````````````````9`0``$@````````````````````````"C`0``
M$@`````````````````````````>`0``$@````````````````````````"9
M`@``$@````````````````````````"2`0``$@``````````````````````
M```D`0``$@`````````````````````````U`0``$@``````````````````
M```````G`@``$@````````````````````````")````$@``````````````
M```````````X`@``$@````````````````````````!R`@``$@``````````
M```````````````F`P``$@`````````````````````````[`0``$@``````
M```````````````````>`P``$@````````````````````````!/`0``$@``
M```````````````````````B`@``$@````````````````````````#A`0``
M$@````````````````````````!6`0``$@````````````````````````!=
M`0``$@````````````````````````!'`P``(0``````````````````````
M``!N`0``$@````````````````````````!"`P``$F`(`$0A````````H`(`
M``````#S`0``$F`)`#Q=````````$`````````"!!```$F`(`&1,````````
M%`H```````"M!0``$F`(`%A:````````F``````````J!```$F`(`!A%````
M````&`````````"0!```$F`'`$@<````````$``````````,!0``$F`(`'A6
M````````X`,```````"3!0``$F`(`#!%````````+`(```````!9`P``$``3
M`'@``@````````````````!O!```$F`(`*!+````````Q`````````".!```
M$F`(`%A#````````9`````````#^!```$F`(`+Q*````````C`````````!@
M!0``$@`(`%Q'````````.`````````!E`P``$``3`.`0`@``````````````
M``"(`P``$F`(`!`D````````3`````````!Z!0``$F`(`)1'````````9`$`
M```````O!0``$0`2`'```@``````"`````````!2`P``$``2`'@``@``````
M``````````!>`P``$@`(`.0C``````````````````"1`P``$F`(`$A+````
M````6``````````4!```$F`(`#1$````````Y`````````"&!0``$F`(`/A(
M````````Q`$`````````;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R<@!R96%L
M;&]C`&%C8V5S<P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P
M:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!?2G9?4F5G:7-T97)#
M;&%S<V5S`'-T<FYC;7``;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R
M5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7V-X
M85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S90!?
M251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N;U]L
M;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P>0!S=')L
M96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E
M<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`
M4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W
M6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E
M=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"UP<&,V
M-&QE+G-O+C$`9G!R:6YT9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`<F5A9&1I
M<@!S<')I;G1F`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN`%]?
M7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`+W5S<B]L:6(O<&5R
M;#4O8V]R95]P97)L+T-/4D4`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`7W-A=F5G<'(P7S(U`%]S879E9W!R,%\R-`!?<V%V96=P<C!?
M,C,`7W-A=F5G<'(P7S(R`%]S879E9W!R,%\R,`!?<F5S=&=P<C!?,S``7W)E
M<W1G<'(P7S,Q`%]S879E9W!R,%\R,0!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M<&%R7V-U<G)E;G1?97AE8P!?<V%V96=P<C!?,CD`7W-A=F5G<'(P7S(X`%]S
M879E9W!R,%\R-@!?<V%V96=P<C!?,C<`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7VUK=&UP9&ER`'AS7VEN:70`7W-A=F5G<'(P7S,P`%]S879E9W!R,%\S,0!?
M<F5S=&=P<C!?,CD`7W)E<W1G<'(P7S(R`%]R97-T9W!R,%\R,0!?<F5S=&=P
M<C!?,C0`7W)E<W1G<'(P7S(S`%]R97-T9W!R,%\R,`!P87)?96YV7V-L96%N
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!?<F5S=&=P<C!?,C4`;7E?<&%R7W!L
M`%]R97-T9W!R,%\R-@!?<F5S=&=P<C!?,C<`7W)E<W1G<'(P7S(X`'!A<E]B
M87-E;F%M90!?<F5S=&=P<C!?,3D`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV
M`'!A<E]F:6YD<')O9P!?<V%V96=P<C!?,3D`<&%R7V-L96%N=7``````````
M`````@``````%@````````````(``````!```@``````%@````````!(8```
M`````!@``@``````%@````````"570```````"@``@``````%@````````!V
M7@```````#```@``````%@````````!O7@```````#@``@``````%@``````
M```\8````````$```@``````%@````````",7@```````$@``@``````%@``
M``````!$8````````%@``@``````%@`````````N8````````&```@``````
M%@`````````S8````````'```@``````%@````````!-8`````````C_`0``
M````)@```#D``````````````!#_`0``````)@```%$``````````````!C_
M`0``````)@```$L``````````````"#_`0``````)@```"<`````````````
M`"C_`0``````)@```$P``````````````##_`0``````)@```#0`````````
M`````#C_`0``````)@```$<``````````````$#_`0``````)@```#T`````
M`````````$C_`0``````)@```%8``````````````%#_`0``````)@```!\`
M`````````````%C_`0``````)@```%P``````````````&#_`0``````)@``
M`%<``````````````&C_`0``````)@```"```````````````'#_`0``````
M)@```$,``````````````!C]`0``````%0```!T``````````````"#]`0``
M````%0```!X``````````````"C]`0``````%0```"$``````````````##]
M`0``````%0```"(``````````````#C]`0``````%0```",`````````````
M`$#]`0``````%0```"0``````````````$C]`0``````%0```"4`````````
M`````%#]`0``````%0```"8``````````````%C]`0``````%0```"<`````
M`````````&#]`0``````%0```"D``````````````&C]`0``````%0```"H`
M`````````````'#]`0``````%0```"L``````````````'C]`0``````%0``
M`"P``````````````(#]`0``````%0```"T``````````````(C]`0``````
M%0```"X``````````````)#]`0``````%0```"\``````````````)C]`0``
M````%0```#```````````````*#]`0``````%0```#$``````````````*C]
M`0``````%0```#(``````````````+#]`0``````%0```#,`````````````
M`+C]`0``````%0```#4``````````````,#]`0``````%0```#8`````````
M`````,C]`0``````%0```#<``````````````-#]`0``````%0```#@`````
M`````````-C]`0``````%0```#H``````````````.#]`0``````%0```#L`
M`````````````.C]`0``````%0```#P``````````````/#]`0``````%0``
M`#X``````````````/C]`0``````%0```#\```````````````#^`0``````
M%0```$````````````````C^`0``````%0```$$``````````````!#^`0``
M````%0```$(``````````````!C^`0``````%0```$4``````````````"#^
M`0``````%0```$8``````````````"C^`0``````%0```$@`````````````
M`##^`0``````%0```$D``````````````#C^`0``````%0```$H`````````
M`````$#^`0``````%0```$L``````````````$C^`0``````%0```$P`````
M`````````%#^`0``````%0```$T``````````````%C^`0``````%0```$X`
M`````````````&#^`0``````%0```$\``````````````&C^`0``````%0``
M`%```````````````'#^`0``````%0```%(``````````````'C^`0``````
M%0```%,``````````````(#^`0``````%0```%0``````````````(C^`0``
M````%0```%4``````````````)#^`0``````%0```%@``````````````)C^
M`0``````%0```%D``````````````*#^`0``````%0```%H`````````````
M`*C^`0``````%0```%L``````````````+#^`0``````%0```%T`````````
M`````+C^`0``````%0```%X``````````````,#^`0``````%0```%\`````
M`````````,C^`0``````%0```&```````````````-#^`0``````%0```&$`
M`````````````-C^`0``````%0```&(``````````````.#^`0``````%0``
M`&,``````````````.C^`0``````%0```&0``````````````/#^`0``````
M%0```&4``````````````/C^`0``````%0```&<```````````````(`3#RX
M8D(XI@((?!```?CA_R'X_0D`2````&"E/@!(````8"``(3@0``'HI@,(?"``
M@$X`````&`!!^/__@CUX?HSII@.)?2`$@$X8`$'X__^"/5A_C.FF`XE](`2`
M3A@`0?C__X(]T'^,Z:8#B7T@!(!.&`!!^/__@CUX?XSII@.)?2`$@$X8`$'X
M__^"/0A_C.FF`XE](`2`3A@`0?C__X(],'Z,Z:8#B7T@!(!.&`!!^/__@CTH
M?HSII@.)?2`$@$X8`$'X__^"/4!^C.FF`XE](`2`3A@`0?C__X(]H'^,Z:8#
MB7T@!(!.&`!!^/__@CVX?HSII@.)?2`$@$X8`$'X__^"/7!_C.FF`XE](`2`
M3A@`0?C__X(]`'^,Z:8#B7T@!(!.&`!!^/__@CUH?HSII@.)?2`$@$X8`$'X
M__^"/9A^C.FF`XE](`2`3A@`0?C__X(]:'^,Z:8#B7T@!(!.&`!!^/__@CU(
M?HSII@.)?2`$@$X8`$'X__^"/?A^C.FF`XE](`2`3A@`0?C__X(]J'^,Z:8#
MB7T@!(!.&`!!^/__@CTX?HSII@.)?2`$@$X8`$'X__^"/5!^C.FF`XE](`2`
M3A@`0?C__X(]2'^,Z:8#B7T@!(!.&`!!^/__@CWH?XSII@.)?2`$@$X8`$'X
M__^"/>!^C.FF`XE](`2`3A@`0?C__X(]Z'Z,Z:8#B7T@!(!.&`!!^/__@CT0
M?XSII@.)?2`$@$X8`$'X__^"/1A_C.FF`XE](`2`3A@`0?C__X(]T'Z,Z:8#
MB7T@!(!.&`!!^/__@CV0?XSII@.)?2`$@$X8`$'X__^"/=A^C.FF`XE](`2`
M3A@`0?C__X(]D'Z,Z:8#B7T@!(!.&`!!^/__@CW(?HSII@.)?2`$@$X8`$'X
M__^"/<A_C.FF`XE](`2`3A@`0?C__X(]@'^,Z:8#B7T@!(!.&`!!^/__@CT@
M?HSII@.)?2`$@$X8`$'X__^"/<!_C.FF`XE](`2`3A@`0?C__X(]\'Z,Z:8#
MB7T@!(!.&`!!^/__@CTH?XSII@.)?2`$@$X8`$'X__^"/?!_C.FF`XE](`2`
M3A@`0?C__X(]0'^,Z:8#B7T@!(!.&`!!^/__@CT@?XSII@.)?2`$@$X8`$'X
M__^"/3!_C.FF`XE](`2`3A@`0?C__X(]@'Z,Z:8#B7T@!(!.&`!!^/__@CWX
M?XSII@.)?2`$@$X8`$'X__^"/8A_C.FF`XE](`2`3A@`0?C__X(].'^,Z:8#
MB7T@!(!.&`!!^/__@CV(?HSII@.)?2`$@$X8`$'X__^"/>!_C.FF`XE](`2`
M3A@`0?C__X(]N'^,Z:8#B7T@!(!.&`!!^/__@CW8?XSII@.)?2`$@$X8`$'X
M__^"/:A^C.FF`XE](`2`3A@`0?C__X(]6'Z,Z:8#B7T@!(!.&`!!^/__@CT8
M?HSII@.)?2`$@$X8`$'X__^"/:!^C.FF`XE](`2`3A@`0?C__X(]L'^,Z:8#
MB7T@!(!.&`!!^/__@CW`?HSII@.)?2`$@$X8`$'X__^"/9A_C.FF`XE](`2`
M3A@`0?C__X(]8'^,Z:8#B7T@!(!.&`!!^/__@CU0?XSII@.)?2`$@$X8`$'X
M__^"/6!^C.FF`XE](`2`3A@`0?C__X(]L'Z,Z:8#B7T@!(!.&`!!^/__@CUP
M?HSII@.)?2`$@$X"`$P\O%U".*8""'SP_\'[^/_A^Q```?AQ_R'X<`"!^&@`
MH?AP`($X:`"A.'P`89!\`&$X>?[_2Q@`0>@```!@6("BZ````&!@@&+H>"ND
M?"'^_TL8`$'H````8&B`(ND```!@0(#BZP``R8L``)XO0`">0(7]_TL8`$'H
M````8```HR_8D6+X$`">0`$`8#@A__]+&`!!Z"7]_TL8`$'H``!_@$']_TL8
M`$'HL0K#FP``?X`Q_?]+&`!!Z(H&(XD"`"EAB@8CF0``?X`9_?]+&`!!Z(H&
M(XD!`"EAB@8CF7P`88#__R`YP``I>04`8SBT!V-\0$BC?QP`G4````!@<(""
MZ/[_8CS;WF,XK?O_2Q@`0>@D'V-X[?K_2Q@`0>A^`*'H<`#AZ````&`!```Y
MR)%B^````&!X&V9\```GZ0``A2\``"/Y_O\B/2CA*3D(`"/Y````8'"!(ND0
M`"/Y_O\B/2OA*3D8`"/Y!``@.<"1(I'__R4Y(``I>0$`*3D(`)U!`0`@.0$`
M*2S__RDYX`""0`0`)3D``$`Y````8-B18NBT!RE]`P"E."0?*7G^_X(\%$HF
M?0``X#BT!Z5\O,2$./C_2?FM_?]+&`!!Z'D;?WP8`()`````8-B18NB]_?]+
M&`!!Z'@;?WP```!@V)%BZ````&"X@<([-?O_2Q@`0>C^_V(\*=]C.*T:`$@`
M`*,O.`">0````&#0D2+I``"I+Q0`GD#^_V(\WMYC.(D:`$@8$'[X````8-"1
M8N@``*,O"`">0=4V`$@```!@V)%BZ*G\_TL8`$'H6?G_2Q@`0>B0`"$X>/OC
M?T`X`$@)`(?H!`!(.;0'2GT!``@Y)!]*>;0'"'T44D9]^/^*^/C^_TL`````
M`````8`"```"`$P\'%M"."@`C(`48H1\>`LC?.0&(7@````XX?\!^*8#"'P1
M``!(9-<!``(`3#SP6D(XI@((?`@`HSC^_^(\/-[G./[_PCQ(G<8X````.1``
M`?CA_R'X`@"#Z/[_8CQ$HF,X1?O_2Q@`0>@``````````8````````!@`@!,
M/*!:0C@```!@````8'^!(CEX@6(X4$@C?0X`J2L@`)U,````8`B`(ND``*DO
M(`">3:8""'QX2RQ]I@,I?1```?CA_R'X&`!!^"$$@$X8`$'H(``A.!```>BF
M`PA\(`"`3@```&````!@``!"8`(`3#PP6D(X````8````&!X@8(X>(%B.%`@
M@WQT'H1\=`Z$?)4!A'P@`()-````8!"`(ND``*DO(`">3:8""'QX2RQ]I@,I
M?1```?CA_R'X&`!!^"$$@$X8`$'H(``A.!```>BF`PA\(`"`3@``0F`"`$P\
MP%E".````&!X@2*)``")+R``GDRF`@A\````8!B`(NGH_Z'[\/_!^_C_X?L`
M`*DO$``!^,'_(?@4`)Y!````8`"!8NCQ^?]+&`!!Z/__(CW__\(_.'PI.3!\
MWCM02-Y_````8("!(NG__T(]=![>?S!\2CG__]X[````8$#PJ7]X4UU]@('B
M.S0`G$`!`"DY)!\J>0``/_DJ4#U]&`!!^*8#*7UX2RQ](02`3A@`0>@``#_I
M0$B^?]3_G4%I_O]+````8""`(ND``*DO%`">0?[_8CS,'6,X3?K_2Q@`0>A`
M`"$X`0`@.0```&`0``'HZ/^AZ_#_P>OX_^'K>($BF:8#"'P@`(!.``!"8`(`
M3#RP6$(XI@((?````&`H@"+I``"I+Q```?CA_R'X'`">00```&#^_V(\B(&"
M.,P=8SB-]_]+&`!!Z/__(CU`?"DY>$LC?0``(^D``*DO(`">0"``(3@0``'H
MI@,(?"C^_TL```!@````8```0F````!@,(`BZ0``J2_8_YY!I@,I?1@`0?AX
M2RQ](02`3A@`0>C`__]+`@!,/!A80CBF`@A\"`!`.:8#27TP`,,XA30`2`']
M(?CPCRWIJ`(A^0``(#DH``$Y"`!&.1``"#DL5"!]"0!&Z?#_*/D@PDEY(@!'
M>2X$*54@1DIY>%,I?2C`ZGAX4RE]'D+G5'@[*7WX_RCYQ/\`0D``(#D@``$Y
MI@,I?7``*.E(`.CH&`!(Z7@Z*7UX4BE]"0!(Z7A2*7VD#RIYP@\I>7A+27T@
M`"EY@``H^=#_`$(```/H(`!CZ1``H^@8`(/H"`##Z#``X>O"+@EXI"X'>'A+
MYWPH`"'I@O#>>"``YWB"6O\_F7G_.V3P''B"6BD]%"+_?YEY*3D46BE]%$KG
M?'@BJ7PX,"E]>"(I?11*YWQD\,EX>/,I?2``ZG@@`#YY*"A)>7CRJ'R"\%UY
M.``(?7@J"'T4^@A]PBY?>7C[*7UX4-]_%$H(?8+P"7AX2YQ_(``;>2``G'LH
M\$IY..#G?'CK77UX.^=_.`#AZ\(N:7LXZ`I]@EK_/YEY_SL4*O]_%/KG?R@H
M9WMX2^=\>-B)?WA3*GU``"'I%#K_?R``^GO"+DA[>-"G?X):*3V9>2DY%/(I
M?8+P?GL42BI]*"A*>WA#2GTH\&A[>/,>?112*7TX\.A_(``Y>7A#Z'Q(`.'H
M*/!?>\(N*GN"6N<\F7GG.!3BYWR"\%Q[>./\?Q0ZZ'PH*"A[..`_?7A3"'UX
MR,I_>/M??5``0>D40N=\(`#[>,(N:7MXV(A_@EI*/9EY2CD4ZDI]@O`]>Q12
M7WTH*'][>$O_?RCP*7MXZSU]%/I*?3CHZ7P@`%IY>$L)?5@``>G"+D=[>-"_
M?X):"#V9>0@Y%/((?8+P?GL40@E]*"A)>W@[*7TH\&=[>//^?!1*"'TX\$=]
M(``9>7@[YW]@`.'K*/!*>\(N*7N"6O\_F7G_.Q3B_W^"\%Q[>.-<?13ZYW\H
M*"=[..`*?7A+YWQXR,E_>%,J?6@`(>D4.O]_(`#[>\(N:'MXV(=_@EHI/9EY
M*3D4ZBE]@O`]>Q1**GTH*&I[>$-*?2CP*'MXZQU]%%(I?3CHZ'\@`#IY>$/H
M?'``X>@H\'][PBY*>X):YSR9>><X%/+G?(+P?GMX\_Y_%#KH?"@H2'LX\#]]
M>%,(?7C0JG]X^U]]>`!!Z11"YWP@`/AX@O!;>\(N"7MXP,A_@EI*/9EY2CD4
MXDI]@O`<>Q127WTH*!][>$O_?RCP27MXVSM]%/I*?3C8Z7P@`%EY>$L)?8``
M`>G"+B=[>,A_?X):"#V9>0@Y%.H(?11""7TH*"E[>#LI?2CP!WMXX_Q\%$H(
M?3C@1WT@`!IY>#OG?X@`X>LH\"I[PBY)>X):_S^9>?\[%/+_?X+P/GMX\UY]
M%/KG?R@H1WLX\`I]>$OG?'C0B7]X4RI]D``AZ10Z_W\@`/U[@O!9>\(NJ'MX
MZ,=_@EHI/9EY*3D4VBE]%$HJ?2@HJGMX0TI]*/!(>WC+&7T44BE].,CH?R``
M.'EX0^A\F`#AZ(+PNGLH\+U[PBX*>WC3NG^"\!M[@EKG/#C0/7V9>><X%.+G
M?!0ZZ'PH*`A[>%,(?7C`*G]XZUU]H`!!Z11"YWP@`/QXPBZ)>WC@2'^"6DH]
MF7E*.13R2GT44EU]*"B=>WA+O7\H\`E[>-L[?13J2GTXV.E\(`!>>7A+"7VH
M``'IPB['>WCP?7^"6@@]F7D(.13*"'V"\)E[*/"<>Q1""7UXRYE_*"C)>W@[
M*7TXR$=]>#NG?[``H>L42@A](``?>7CX*7_"+OQ[@EJ]/YEYO3L4TKU_@O#:
M>RCPWGL4ZJ=_>-/:?R@HYWO(`,'K.-`*?7CCYWQX4RI]N``AZ10ZO7\@`+=[
MVF[>/\(NZ'IXN%Q_@EHI/:'KWCN9>2DY%-+>?Q3:*7T42BI]*"CJ>GA#2GUD
M\.A[@O#_>Q12*7UX^PA](``X>=``X>L@`!MYPBX*>SC8IW^"\/UZ>#N'?\``
M@>O:;O\_H>O_.Q3:_W^"6IP_F7F<.Q3*G'\4XH=_*"@'>WA3YWQD\.IZ>.M=
M?10ZG']XZ@I](`"9>WA*2GW"+BA[(`!*>2@H*7L4\DI]9/`>>X+P&'MX0RE]
M>,/>?Q1*2GUX\J=_(`!:>7CBYWS"+DA[*"A)>R``YWAX0RE]%/KG?-@``>D4
M2N=\9/`I>X+P.7L@`+U[>,LY?=IN"#UXRLE_H>L(.7A2*GT@`/QX%.H(?2``
M2GG"+HE[%%((?2@HBGMD\%M[>$M*?8+P6GO@`"'I>--[?Q12"'T@`!UY>-HJ
M?W@Z1WTH**Q[PBZJ>]IN*3UX4XQ]Z`!!Z2``WGMD\)][H>LI.8+PG'L4\BE]
M>./_?R``YW@4.BE]VFY*/7CZ9W\48BE]\`"!Z2``.7MX0NA\H>M*.2``/GD4
MRDI](``(>63PO'N"\+U[>.N<?Q1"2GTH*,=[PB[(>WA#YWS:;HP]>.+H?Q0Z
M2GWX`.'H(`![>WA*"7VAZXPY(`!9>13:C'T@`"EY9/#=>X+PWGMX\[U_%$J,
M?2@H*'O"+BE[>$L(?=INYSQXZHE_%$*,?0`!`>D@`/][>%(J?:'KYS@@`)IY
M%/KG?"``2GD44N=\*"A)>\(N2GMD\#Y[@O`Y>WA3*7UXR]Y_%$KG?-IN"#UX
M\JE_(`#X>"``G'MX8BQ]H>L(.<(N"7L4X@A](`",>2@H"GMX2TI]%&((?0@!
M(>ED\%M[@O!:>WC3>W\44@A](``9>7C:RG]X.D=]*"@L>\(N*GO:;BD]>%.,
M?1`!0>D@`+U[9/`?>Z'K*3F"\!A[%.HI?7C#_W\@`.=X%#HI?=IN2CUX^F=_
M%&(I?1@!@>D@`-Y[>$+H?*'K2CD@`#IY%/)*?2``"'ED\#Q[@O`Y>WC+G'\4
M0DI]*"A'>\(N2'MX0^=\VFZ,/7CBZ'\4.DI](`'AZ"``>WMX2@E]H>N,.2``
M6'D4VHQ](``I>63P77N"\%I[>-.]?Q1*C'TH*`A[PBX)>WA+"'W:;N<\>.J)
M?Q1"C'TH`0'I(`#_>WA2*GVAZ^<X(`"9>13ZYWP@`$IY%%+G?"@H*7O"+BI[
M9/`>>X+P&'MX4RE]>,/>?Q1*YWS:;@@]>/*I?R``^G@@`)Q[>&(L?:'K"#G"
M+DE[%.((?2``C'DH*$I[>$M*?11B"'TP`2'I9/`[>X+P.7MXRWM_%%((?2``
M&'EXVLI_>#I'?2@H#'O"+@I[VFXI/7A3C'TX`4'I(`"]>V3P7WNAZRDY@O!:
M>Q3J*7UXT_]_(`#G>!0Z*7W:;DH]>/IG?Q1B*7U``8'I(`#>>WA"Z'RAZTHY
M(``Y>13R2GT@``AY9/`<>X+P&'MXPYQ_%$)*?2@H)WO"+BA[>$/G?-INC#UX
MXNA_%#I*?4@!X>@@`'M[>$H)?:'KC#D@`%IY%-J,?2``*7D42HQ]*"A(>\(N
M27MD\#U[@O`Y>WA+"'UXR[U_%$*,?5`!`>EXZHE_VF[G/"``FWD@`/][>%(J
M?:'KYSC"+FE[%/KG?"``2GDH*'][9/!>>X+P6GMXT]Y_%%+G?'A+_W_:;@@]
M%/KG?WCRJ7]8`>'H(`#W>R``G'MX8BQ]9/!Z>Z'K"#F"\'M[>-M:?\(NZ7H4
MX@A](`",>2@HZGH48@A]>$M*?=IN)SUXTL=_%%((?2``O7MX^N=\H>LI.2``
M&7D4ZBE](`#G>!0Z*7TH*"I[PBXG>V3P^WIX.TI]@O#W>A12*7U@`4'I>+M[
M?WC:1W\@`-Y[>$+H?"``.'G:;DH](``(>:'K2CED\#Q[%/)*?8+P.7MXRYQ_
M%$)*?2@H!WO"+@A[>$/G?'CC:'\X2`A]..!I?Q0ZZGQX2PA]:`$AZ1N/0#T@
M`/]XW+Q*863P'7L@`$IY@O`8>Q1**GT@`%I[>,.]?Q3227\H*.Q[PB[I>R``
M"'EX2XQ]%-((?7CKB7\48HA].#@I?3CHB'\@`)EY>$,I?7`!`>ED\/Y[(`![
M>X+P_WMX^]Y_*"@G>Q1""GT@`"EY%-IH?\(N*'L4VBE]>$/G?'CSJ'\4.NE\
M.&`(?3CPJ7]X2PA]>`$AZ2``^GAD\#][(`"<>X+P.7LH*$Q[%$HJ?7C+_W\4
MXHE_(``(><(N27L4X@A]>$N,?7C[R7\48HA].#@I?3CXR'\@`)AY>$,I?8`!
M`>ED\%M[(`"]>X+P6GMXTWM_*"@'>Q1""GT@`"EY%.JH?\(N"'L4ZBE]>$/G
M?'C;Z'\4.NE\.&`(?3C8Z7]X2PA]B`$AZ2``^7AD\!Q[(`#>>X+P&'LH*"Q[
M%$HJ?7C#G'\4\LE_(``(><(N*7L4\@A]>$N,?7CC:7\48HA].#@I?3C@:'\@
M`)IY>$,I?9`!`>ED\#U[(`#_>X+P.7MXR[U_*"A'>Q1""GT@`"EY%/KH?\(N
M2'L4^BE]>$/G?'CKB'\4.NE\.&`(?3CHB7]X2PA]F`$AZ2``^'AD\%Y[(`![
M>X+P6GLH*`Q[%$HJ?7C3WG\4VFE_(``(><(N"7L4V@A]>$N,?7CSJ7\48HA]
M.#@I?3CPJ'\@`)EY>$,I?:`!`>ED\!][(`"<>X+P&'MXP_]_*"@G>Q1""GT@
M`"EY%.*(?\(N*'L4XBE]>$/G?'C[R'\4.NE\.&`(?3CXR7]X2PA]J`$AZ2``
M^GAD\#M[(`"]>X+P.7LH*$Q[%$HJ?7C+>W\4ZJE_(``(><(N27L4Z@A]>$N,
M?7C;Z7\48HA].#@I?3C8Z'\@`)AY>$,I?;`!`>ED\%Q[(`#>>X+P6GMXTYQ_
M*"@'>Q1""GT@`"EY%/+(?\(N"'L4\BE]>$/G?'CC:'\4.NE\.&`(?3C@:7]X
M2PA]N`$AZ2``^7AD\!U[(`#_>X+P&'LH*"Q[%$HJ?7C#O7\4^NE_(``(><(N
M*7L4^@A]>$N,?7CKB7\48HA].#@I?3CHB'\@`)IY>$,I?<`!`>ED\#Y[(`![
M>X+P.7MXR]Y_*"A'>Q1""GT@`"EY%-IH?\(N2'L4VBE]>$/G?'CSJ'\4.NE\
M.&`(?3CPJ7]X2PA]R`$AZ2``^WAD\%][(`"<>X+P6GLH*&Q[%$HJ?7C3_W\4
MXHE_(``(><(N:7L4X@A]>$N,?7C[R7\48HA].#@I?3CXR'\@`)QY>$,I?=`!
M`>ED\'I[(`"]>X+P>WMXVUI_*"B'>Q1""GT@`"EY%.JH?\(NB'L4ZBE]>$/G
M?'C3Z'\4.NE\.&`(?3C0Z7]X2PA]V`$AZ2``_7AD\)M[(`#>>X+PG'LH**Q[
M%$HJ?7CC>W\4\LE_(``(><(NJ7L4\@A]>$N,?7C;27\48HA].#@I?3C82'\@
M`)YY>$,I?>`!`>ED\+Q[(`#_>X+PO7MXZYQ_*"C'>Q1""GT@`"EY%/KH?\(N
MR'L4^BE]>$/G?'CC:'\4.NE\.&`(?3C@:7]X2PA]Z`$AZ2``^'AD\-U[(`!:
M>X+PWGLH*`Q[%$HJ?7CSO7\4TDE_(``(><(N"7L4T@A]>$N,?7CKB7\48HA]
M.#@I?3CHB'\@`)EY>$,I??`!`>ED\!Y[(`![>X+P&'MXP]Y_*"@G>Q1""GT@
M`"EY%-IH?\(N*'L4VBE]>$/G?'CSJ'\4.NE\.&`(?3CPJ7]X2PA]^`$AZ2``
MG'L@`/MX(``(><(N?WL@`+U[%$HJ?13BB7\H*&E[%.((?63P/'N"\#E[>/LI
M?7C+G'\42@A]>./)?R``&GDX."E]..#'?W@[*7T``N'H"`+AZR``WGL@`"EY
M%#I*?<(N1WL4ZDI]%%))?2@H27MX.RE]%$I*?63P:7N"\'M[(`!7>7C;.WUB
MRB`]UL$I87C:AW\@`"EY>$+H?!3ZZ7\@``AY%/+_?\(NYWH40O]_*"CH>G@[
M"'T0`N'H(`"<>Q1"_W]D\$A[@O!:>R``^7MXTQI]%#KI?'C2:'\4XN=\>%(*
M?<(N*'L@`$IY9/#]>A12YWPH*"I[>$-*?8+P]WH8`@'I>+N]?Q12YWP@`/AX
M>.I*?WCZ7WTH*`Q[PBX*>Q1""7UX4XQ](`![>R`"0>ED\#Y[@O`Y>WC+WG\4
MV@A](`#_>Q1227T4^@A]>/*_?Q1B"'T@`%I[*`*!Z7@ZYW\@`!QY%-)*?2``
MYWAD\!I[@O`8>WC#6G\4.DI]*"B?>\(NAWMX._]_>-+'?Q3Z2GT48HE],`+A
MZR``O7MX0NA\(`!9>13JC'T@``AY9/";>X+PG'L40HQ]>.-[?\(N*'LH*"=[
M%/KI?WA#YWQXVDA_%#J,?2``WGLX`N'H>%(*?2``EWD4\O]_(`!*>112_W\H
M*.AZPB[J>F3P/'N"\#E[>%,(?7C+G'\40O]_>.)J?R``^'L4.NE\(`!:>WAB
M3'W"+@A[%-+G?"``C'DH*`I[%&+G?'A#2GUD\/UZ0`(!Z8+P]WH44N=\>+N]
M?R``^7AXZHI_*"@L>WCZ7WW"+BI[>%.,?11""7U(`D'I(`![>V3P'GN"\!A[
M%-H(?7C#WG\@`/][%/H(?7CROW\48@A]%%))?5`"@>D@`)Q[>#KG?R``%WD4
MXDI](`#G>&3P.GN"\#E[%#I*?7C+6G_"+N=Z*"C_>A1BB7UX._]_>-+'?Q3Z
M2GT@`+U[6`+AZWA"Z'P@`%AY%.J,?2``"'ED\/MZ@O#W>GB[>W\40HQ]*"@'
M>\(N"'MX0^=\>-I(?Q0ZC'T4^NE_8`+AZ"``WGMX4@I](`"9>13R_W\@`$IY
M*"@H>Q12_W]D\!Q[PBXJ>X+P&'MXPYQ_>%,(?11"_W]XXFI_(`#W>Q0ZZ7P@
M`%I[>&),?<(NZ'H4TN=\(`",>2@HZGIX0TI]%&+G?&@"`>ED\#U[@O`Y>WC+
MO7\44N=\(`#X>'CJBG]X^E]]*"@,>\(N"GL40@E]>%.,?2``>WMP`D'I9/#^
M>H+P]WIXN]Y_%-H(?2``_WL44DE]%/H(?7CROW\48@A](`"<>W@"@>EX.N=_
M(``9>13B2GT@`.=X9/`:>X+P&'MXPUI_%#I*?2@H/WO"+B=[>#O_?WC2QW\4
M^DI]%&*)?8`"X>L@`+U[>$+H?"``5WD4ZHQ](``(>63P.WN"\#E[%$*,?7C+
M>W_"+NAZ*"CG>A3ZZ7]X0^=\>-I(?Q0ZC'T@`-Y[B`+AZ'A2"GT@`)AY%/+_
M?R``2GD44O]_*"@(>\(N"GMD\/QZ>%,(?8+P]WH40O]_>+N<?R``^7MXXFI_
MPBXH>Q0ZZ7P@`%I[>&),?2@H*GL4TN=\>$-*?63P'7N0`@'I(`",>8+P&'MX
MP[U_%&+G?!12YWQXZHI_%$()?7CZ7WT@`'M[(`#Z>"``_WL4V@A]%/H(?<(N
M2GLH*%][9/`^>WA3_W^8`D'I@O`Y>WC+WG\@`)Q[%/KH?Q1:?GT44DE](`#H
M>Q3B2GUX\KQ_>#J'?\(N''D@`.=X(`"]>Q0Z2GTH*`=Y>./G?(+P''D4.DI]
M9/!'>X+P6GL@`$IY>-/Z?*`"X>@H\`AY>.,(?10BFGP4*JA\(`"$>!0Z*7UX
MTL=_>/K_?!3J*7T8`(/X(`#_>R@H1WD4^BE]PBY?>7C[YWP44D9]%#HI?2``
M2GD4`BE](`"E>"``*7D@`&MY"`!#^1``H_@``"/Y(`!C^:@"0>GPCRWI>4I*
M?0``(#D,`()!7>+_2Q@`0>@``R$XK!X`2``````````!@`D```(`3#S<04(X
MI@((?&$>`$AY&WQ\L?\A^```P#L@`()!````8#B`(ND``,`[>..%?P``J>L`
M`+TO'`">0%``(3AX\\-_9!X`2#T`B2L4`)Y!`0"E.```)8D``*DO[/^>0%`H
MO'QX(YI\M`>_?'CKNW\``-OK``"^+\3_GD%X^^5_>..$?WCSPW^)W_]+&`!!
MZ```HR\H`)Y`KO@^?3T`B2\<`)Y`4-B]?P$`_SMT'KU_%/K>?P``NI.$__]+
M"`![.[#__TL``````````8`&```"`$P\#$%".*8""'P0``'XD?\A^&0`@3CP
MCRWI:``A^0``(#D5__]+:`!!Z?"/+>EY2DI]```@.0P`@D$UX?]+&`!!Z'``
M(3@0``'HI@,(?"``@$X``````````8`````"`$P\K$!".*8""'SP_\'[^/_A
M^W@;?WP0``'X@?\A^/"/+>EH`"'Y```@.60`P3MX\\1_>/OC?Z'^_TL``*,O
M(`">0&@`(>GPCTWI>5(I?0``0#D\`()!N>#_2Q@`0>AF`"'I````8#B``NDD
M'REY^/]).0``*.D44BE]$`!)Z0``JB\)`$GY]/^>0*3__TN``"$X"!T`2```
M```````!@`(```(`3#P(0$(XI@((?(D<`$A1_R'X>!M]?/"/+>EH`"'Y```@
M.0``)(D]`"EI-``I?7[9*5442N1_>/OC?_'>_TL8`$'H9`"!.'@;?'QXZZ-_
MY?W_2WD;?GQ,`()!T=[_2Q@`0>A`&+Q_]`"=0?___SO__]X[`0`_C0``J2\!
M`#Z=]/^>0```8#AH`$'I\(\MZ7E*2GT``"`Y<`&"0='?_TL8`$'H````8#B`
M8NL``,`[``!;Z_C_6CD)`"KI``"I+T``GD````!@N($B@0(`GC@``(DO.`">
M0;0'A'QXTT-_)!^$>`G=_TL8`$'H``"C+P``>_A0`)Y`__]@.(S__TL!`-X[
MM`?>?[#__TL!`"`Y````8+0'A'PD'X-XN($BD3W@_TL8`$'H>1MY?,S_@D$D
M'\5[>--$?^W@_TL8`$'H```[^P$`/CD``%OI````.20?*7DJ20I]9`#!DWCK
MHW\``".)``"I+X``GD!F`,'K````8#B`8NM0&'U\`@"<.[0'8WP4XF-\``!;
MZ]'?_TL8`$'H)!_>>P``HR\J\7I\6/^>068`(>D``%OI__^].R0?*7DJ2"I]
M`0!=C0``JB\``$F9-`">0#T`0#G___\[``!)F0$`7XT``*HO`0!)G?3_GD"@
M_O]+/0")*X#_GD$!`&,X;/__2ST`BBO,_YY!`0`I.;3__TNP`"$XQ!H`2```
M```````!@`<```(`3#SL/4(XI@((?&D:`$C!_B'X>1M]?/"/+>GX`"'Y```@
M.6@`@D$``#V)``")+UP`GD$UW_]+&`!!Z'D;?'Q,`()!_O]B/_[_0C_^_R(_
ME=Y[.Y3>6CN7WCD[:``!.WCC@W\)V_]+&`!!Z'D;?WPX`()`>..#?_W<_TL8
M`$'H>.NC?T7>_TL8`$'H^`!!Z?"/+>EY2DI]```@.=0`@D&QW?]+&`!!Z!,`
M_SMXVV1_>/OC?VG?_TL8`$'H``"C+Z#_GD%XTT1_>/OC?U'?_TL8`$'H``"C
M+XC_GD%XZZ-_,=S_2Q@`0>AX&WY\>/OC?R'<_TL8`$'H%/)C?`(`8SBT!V-\
M/=[_2Q@`0>AX^^9_>.NE?WC+)']X&WY\O=S_2Q@`0>AXPP1_>//#?Y7;_TL8
M`$'H__^#+WCSPW\H`)Y!@``A@28$*54`0(DO&`">0+G^_TMX\\-_M=K_2Q@`
M0>@`__]+&=[_2Q@`0>CH__]+0`$A.#P9`$@``````````8`(```"`$P\:#Q"
M.*8""'SP_\'[^/_A^W@;?GP```!@0(#BZQ```?C1_R'X``!_@&7<_TL8`$'H
M``*#.'CSPW\%W/]+&`!!Z```HR\0`)Y!``!@.#``(3@$&0!(``!_@#7<_TL8
M`$'H&`(C@28$*54`0(DO(`">0`(`@#AX\\-_^=G_2Q@`0>@T`&-\?MEC5,3_
M_TL``'^`_=O_2Q@`0>@8`B.!)@0I5?__*FT`H(HOH/^>0,3__TL`````````
M`8`"```"`$P\J#M".*8""'P```!@0(`BZ1```?CA_R'X``!I@+';_TL8`$'H
M````8$B`HNC^_\(\_O^"/&C>QCB=WH0X#=W_2Q@`0>@@`"$X$``!Z*8#"'P@
M`(!.``````````&``````@!,/$0[0CBF`@A\^/_A^P```&!`@.+K$``!^-'_
M(?@``'^`2=O_2Q@`0>AY__]+``!_@#G;_TL8`$'H_O_B//[_HCPGX><X_O^"
M/````#EX.^9\>->E.+G>A#B5V?]+&`!!Z#``(3C0%P!(``````````&``0``
M`@!,/,PZ0CBF`@A\71<`2&'?(?CPCRWI>"`A^0``(#D=V?]+&`!!Z&@`X3O^
M_\(\_O^"/'@;97S.WL8XTMZ$.'C[XW]UVO]+&`!!Z```@R\H`)Q```#`.W@@
M0>GPCRWI>4I*?0``(#EX\\-_9`""0<':_TL8`$'H<!"A.WC[XW\`$*`X>.ND
M?Y7:_TL8`$'HM`=_?```GR^\_YQ!`0!_.+0'8WQ]V_]+&`!!Z'D;?GRH_X)!
M>/OE?WCKI'^YU_]+&`!!Z```(#FN^3Y]C/__2Z`@(3C0%@!(``````````&`
M`P```@!,/.@Y0C@<__]+`````````````````@!,/-`Y0CBF`@A\)H"0?0@`
M@9$Y%@!(,>\A^'@;?GS^_V(\WMYC.'@CGWSPCRWI:!`A^0``(#F5^/]++P"`
M.'@;>GQX\\-_Y=?_2Q@`0>@``*,O-`">0?[_8CQX\\1_Y]YC.&WY_TMH$"'I
M\(]-Z7E2*7T``$`Y>//#?Y0!@D&UV?]+&`!!Z'CSPW_^_X(_9=C_2Q@`0>CT
MWIP[_O\B/WCCA'_^_^(^M`=[?'C[XW]-VO]+&`!!Z/[_PCX``*`Z```Z+I7>
M.3MX&W]\````.P$`>SOVWO<ZT-_6.F@`H3L`@+5B``"_+W#_GD$``#^)``")
M+P@`GD!XRS]_(`"207C[Y']XTT-_^=K_2Q@`0>AXXX1_``"C+^@`GD%X^^-_
MU=?_2Q@`0>BT!V-\%!H_??__*8DO`(DOL`">010:>WS_#X,O%/^=07C[Y7]X
M\\=_>+OF?GBSQ'YXZZ-_8=C_2Q@`0>@```!@0(#BZP``?X")V/]+&`!!Z``"
M@SAXZZ-_)=?_2Q@`0>@``*,O;`">0```?X!EV/]+&`!!Z!@"(X$F!"E5`*B)
M?U``GD`!`(`X>.NC?RG6_TL8`$'H``"C+S@`GD#^_V(\>.ND?^?>8S@!^/]+
M>.NC?ZG7_TL8`$'H>!M^?(3^_TO__V,XM`=C?*X9'W\X__]+>..$?P``8#C]
MV/]+&`!!Z'@;?WS8_O]+T!`A.`@`@8$@@9!];!0`2``````````#@`L``/__
M0SD!`"J)`0`*.0``J2\(`)Y`(`"`3B\`B2L(`)Y``@!J.'A#"GW<__]+````
M`````````````@!,/&PW0CBF`@A\^/_A^WD;?WSP_\'[$``!^-'_(?@0`()!
M``#?BP``OB\<`)Y`_O]B/)7>8SCEUO]+&`!!Z#``(3@8%`!(2=;_2Q@`0>C_
M_R,Y%$J_?'@;:7P4&G]\__]C.$`8OW\,`)U!__^_+P@`GD`!`"`Y`0`I+/__
M*3FL`()!``!%B2\`BB^(`)Y!__]%.5`H/WU`4+]_"`"=0`$`(#D``$6)+P"*
M+W``GD#__T4Y4"@_?4!0OW\,`)U!__^_+P@`GD`!`"`Y`0`I+/__I3C__RDY
M<`""0%`HOWP``&`X`@`E.0`0J2M4_YU!````8`$`I3C`@<([>/OD?WCSPW\)
MU_]+&`!!Z'CSPW\P__]+__^E.&#__TL!`"DL__^E./__*3E\_X)`0"B_?X#_
MGD`O`)XK^/Z>0?[_8CSVWF,X]/[_2P``18DO`(HO?/^>08C__TL`````````
M`8`"```"`$P\"#9".*8""'S^_T(]:-Y*.?[_8CSXWF,XA1(`2%'_(?C^_\(_
M_O^B/QG?WCO>WKT[_O_B/_[_@C\UW_\[/]^<._"/+>F(`"'Y```@.0H`*CD`
M`,GH"`#IZ!``">D8`$GI(``IH6``P?AH`.'X<``!^7@`0?F``"&QZ?3_2_[_
M8CP!WV,XW?3_2_[_8CP)WV,XT?3_2_[_8CP2WV,XQ?3_2WCSPW^]]/]+_O]B
M/"G?8SBQ]/]+>.NC?ZGT_TMX^^-_H?3_2WCC@W^9]/]+_O]B/$G?8SB-]/]+
M_O]B/.?>8SB!]/]+_O]B/%/?8S@5]/]+>1MD?`P`@D%XXX-_"?7_2_[_8CQD
MWV,X^?/_2WD;9'P0`()!_O]B/';?8SCI]/]+_O]B/('?8SC9\_]+>1MD?#@`
M@D%XZZ-_S?3_2_[_@CQX\\-_Q."$.+WT_TN(`$'I\(\MZ7E*2GT``"`Y4`""
M00G5_TL8`$'H_O]B/)'?8SB1\_]+>1MD?`P`@D%X^^-_N/__2_[_@CP*`*`X
MHM^$.'$`83BETO]+&`!!Z```HR^<_YY`>P"!.-3__TNP`"$X*!$`2```````
M```!@`0```(`3#Q$-$(X````8`B!(H'__XDO8`">0*8""'S^_V(\-=]C.!``
M`?BA_R'X%?/_2P``0#D``",L'`""00``(XD``*DO$`">03``*6G__TDQ$$E*
M?6``(3@```!@$``!Z`B!0I$```!@I@,(?`J!8N@@`(!.````8`J!8N@@`(!.
M``````````&``````@!,/+@S0CBF`@A\$``!^.'_(?AMU/]+&`!!Z/W2_TL8
M`$'H```C+!P`@D$``"/I(``A.'A+(WT0``'HI@,(?"``@$X``"`YZ/__2P``
M```````!@`````(`3#Q@,T(XI@((?.T/`$B!_R'X_O_"/W@;?WRMW]X[>//#
M?SGR_TMX^^1_>1M]?!``@D$``#V)``")+Q0`GD!X\\-_'?/_2X``(3CH#P!(
M7=+_2Q@`0>@``*,O[/^>0'C[XW\ATO]+&`!!Z'@;?'QXZZ-_$=+_2Q@`0>@4
M&GQ\`@!C.#'4_TL8`$'H_O_"//[_@CS0WX0X>.NG?W@;?'STWL8X>/OE?Z72
M_TL8`$'H>..$?XS__TL``````````8`$```"`$P\G#)".*8""'P```!@$($"
MZ0```&`8@4+I````8""!(NGM#@!(__\`//[_0C_P?0!@WMY:.W@;>'QXTT-_
M:@$A?*"!X3L!`,$\\(_MZ)B!YO@``.`X````8"B!XNC0?A_YV'Y?^0```&`P
M@0+I````8#B!0NG@?C_Y````8$"!(ND`?__X"'\?^1!_7_D8?S_Y````8$B!
M0ND```!@4($BZ0```&!8@0+I(']?^2A_/_D```!@8(%"Z0```&!H@2+IZ'X?
M^?!^7_GX?C_YR?#_2WD;?GQ(`()!```^B0``B2\\`)Y!7?[_2WCSPW]=T?]+
M&`!!Z'@;?'P!`,$\>..#?YB!YNCPC\WH>3+G?```P#CL"()!Z='_2Q@`0>C-
M_?]+>1M^?-0!@D%X\\-__O]B/XW0_TL8`$'H___>.\3?>SND#V-X`0!C.*72
M_TL8`$'H>!M\?'@;?7P!`+Z,``"E+Z0!GD```,`[`']_.RK8OG\``+TO/`">
M07CKHW\9\/]+>1M]?)@!@D$``#V)``")+XP!GD&E]/]+``"C+X`!GD%XZZ-_
MI=#_2Q@`0>AX&WU\``!@.]!^/SL``+TO'`">0"K(VW\``+XO$`">00``/HD`
M`(DO4`&>0'CKHW_^_R(_W<__2Q@`0>CVWCD[>!M^?'CC@W_)S_]+&`!!Z!3R
MPW\$!-X[M`?>?WCSPW_AT?]+&`!!Z/[_XCS^_X(\>..(?\G?YSAXRR9_>.NE
M?\[?A#AX&WM\4=#_2Q@`0>C``8`X>-MC?R'2_TL8`$'H__^#+_P`GD#AS_]+
M&`!!Z```(X$1`(DOZ`">00```&!0@"+I``#XZP``*>EH`"'YN<__2Q@`0>C^
M_X(\>-MF?WC[Y7_7WX0X`@#CZ&@`8>B1S?]+&`!!Z```@#M0_O]+Z>[_2P``
MP#MY&VE\'`""00``*8D``(DO$`">08'/_TL8`$'H>!M^?```OB\(`+T[3/Z>
M0"K@?7P``*,OQ/^>0/[_PC^]W]X[-/[_2P``H#OH?I\[X/__2WCKHW]XVV1_
M><__2Q@`0>@"`+T[0/[_2P@`WCM,_O]+>//#?Q'S_TL``*,O%`">07CSPW\1
MS_]+&`!!Z'@;?7P(`'L[</[_2P```&!`@(+K``!\@&G/_TL8`$'H``*#.'C;
M8W\)S_]+&`!!Z'D;?7Q@!H)```!\@$7/_TL8`$'H&`(C@28$*54`0(DO1`:>
M0```?(`IS_]+&`!!Z!P"XX*]S_]+&`!!Z`"X@W\D!IY```!\@`G/_TL8`$'H
M&`(C@?X%*57``8DO"`:>0'CSPW\9T/]+&`!!Z'@;?'S^_V(\N-]C.*WM_TL`
M`*,O)`">00``V.M1SO]+&`!!Z'@;9'QX\\-_R?3_2WD;=WP(`()```#XZGB[
MXWZAS?]+&`!!Z+0'?GP#`)XOB`"=0/S_?CC^_X(\$N"$.!0:=WR)T/]+&`!!
MZ```HR]H`)Y`!`">+QP`GD'\_]X[M`?>?Q3RUW___SZ)+P")+T@`GD`(`-CK
M``"^+SP`GD%X\\-_/<W_2Q@`0>@#`*,K*`"=0/S_8SC^_X(\%^"$.!0:?GPI
MT/]+&`!!Z```HR\(`)Y`>//7?ZGY_TL``*,O9`2>0```@#AXN^-^"<W_2Q@`
M0>AY&WA\3`2"00(`H#CN_X`XP<__2Q@`0>CX?]\[!@"@.'CSQ']XPP-_7<O_
M2Q@`0>CX?S^)``")+[0`GD#Y?S^)0P")+Z@`GD#Z?S^)00")+YP`GD#[?S^)
M0P")+Y``GD#\?S^)2`")+X0`GD#]?S^)10")+W@`GD`"`*`XQO^`.'C#`W]-
MS_]+&`!!Z"D`H#AX\\1_>,,#?^W*_TL8`$'H_O\"/7CSQW\GX0@Y_O^"/'C+
M)G]XVV5_'."$.'CC@W_US/]+&`!!Z'C;8W\=R_]+&`!!Z'CCA']XTT-_[>S_
M2WCC@W^-^?]+0/O_2P``H#@``(`X>,,#?___H#K5SO]+&`!!Z$5G(#WX?]\Z
M`2,I82`$M58P?Y\Z:']_.C!_/_G-[R`]B:LI82``*7DX?S_YNI@@/?[<*6$@
M`"EY0'\_^3(0(#UV5"EA2'\_^=+#(#WPX2EA(``I>5!_/_D``"`Y6'\_^6!_
M/_FH?S^1>*NE?GBSQ'YXPP-_#<K_2Q@`0>BT!WU\``"=+Z0!G4%XPP-_:'\?
M.\W*_TL8`$'H6'_?ZX#_0#E@?[_KHN[%>[0'J7P!`*4X.`"%+[0'HWRN25A]
M%!IX?'P"G4!``*4@``"`.+0'I7PP?_\ZM<O_2Q@`0>AXN^-^U=/_2S@`H#@`
M`(`X>,,#?YG+_TL8`$'H`D:I>S!_?SBC?[^;IW_?F_[_`C^P?_\ZH'\_F0*$
MJ7O$WQ@[H7\_F0+"J7O(?[\[HG\_F0)&R7ND?S^9`H3)>Z5_/YD"PLE[``#`
M.Z9_/YEMT_]+,'\_Z0)&*GFS?S^9L']?F0*$*GFQ?U^9`L(J>3A_/^FR?U^9
M`D8J>;=_/YFT?U^9`H0J>;5_7YD"PBIY0'\_Z;9_7YD"1BIYNW\_F;A_7YD"
MA"IYN7]?F0+"*GE(?S_ING]?F0)&*GF_?S^9O']?F0*$*GF]?U^9`L(J>5!_
M/^F^?U^9`D8J><-_/YG`?U^9`H0J><%_7YD"PBIYPG]?F:[PMWRD#\-[>,,$
M?Q0:?7P!`-X[L<K_2Q@`0>@4`+XKX/^>0```(#G^_P(])^$(.7CKIW_P?S^9
MA/W_2UA_7^DD'ZE[%%(I?2``*7E`2*I_$`"=0&!_7^D!`$HY8']?^:I_?^A@
M?U_I6'\_^4(?J7L``*,O%$HJ?6!_/_E<`)Y!0``C(7CKMW\`2)U_"`"=0'A+
M-WVT!_Y^>+/$?GCSQ7\4&G-\W<?_2Q@`0>BH?S^!%+HI?4``B2^H?S^1P/V>
M0%#HMW\4\M9_M`>]?WBC@W[YT?]+"```2/A_WSL_`)TO(`"=07CKI7]X\\1_
M>)MC?I''_TL8`$'HJ'^_DX#]_TL``/[H"``>Z1``7ND8`#[IP/^].T``WCNT
M![U_:'__^'!_'_G@__[HZ/\>Z7A_7_F`?S_Y\/]>Z?C_/NF(?__XD'\?^9A_
M7_F@?S_Y@/__2S@`I2```(`XM`>E?*C]_TO^_X(\_O]B/,3@A#@UWV,X:>G_
M2_[_XC_^_\(_)^'_.SG@WCO%Q_]+&`!!Z/[_@CQX^^A_>,LF?WC;97]X&V=\
M*^"$.'CC@W\=R?]+&`!!Z,`!@#AXXX-_[<K_2Q@`0>C__X,O%/R>0*W(_TL8
M`$'H```C@1$`B2\`_)Y`;<?_2Q@`0>@!`+T[>/OI?[0'O7]XRR9_>!MG?'CK
MJ']XVV5_>//$?WCC@W^]R/]+&`!!Z*#__TL```!@4(`BZ0``N.C^_X(\>-MF
M?TK@A#@``&GH/<;_2Q@`0>BL^/]+```AZ$@%`$@``````````8`-```"`$P\
MB"A".*8""'P%!0!(8?\A^````&!`@.+K``!_@)'(_TL8`$'H>!M^?```?X"!
MR/]+&`!!Z+@`(XG^_V(\&=]C.+D`/ID]Y_]+```C+!P`@D$``".),0")+Q``
MGD`!`".)``")+P@`GD$=\O]+``!_@````&"X@<([-<C_2Q@`0>C^_X(\"P#`
M.`$`H#B=X(0XM<;_2Q@`0>@``",LE`""0```?X`)R/]+&`!!Z/[_@CP#`,`X
M`0"@.*+@A#B)QO]+&`!!Z'D;?7QH`8)```!_@-W'_TL8`$'H_O^"/`,`P#@!
M`*`XJ>"$.%W&_TL8`$'H>1M]?,P!@D'^_V(\Y]YC.('F_TMY&WQ\@`&"00``
M?X"=Q_]+&`!!Z!``/>EXXX5_``")Z#'%_TL8`$'HE`$`2!``(^D@```_``"@
M.P`$&&,H`$GK"!`^@0$`G3NT!YM_`.")?RP`G4```'^`4<?_2Q@`0>@``,`X
M>.NE?WC31'\9R/]+&`!!Z'D;>7Q,`()`````8,"1(H'__RDY`.B)?Q#_GD`!
M`*`["!`^@0#HB7\`_YU```!_@`$`O3NT![U__<;_2Q@`0>AXTT1_W<;_2Q@`
M0>C4__]+$!`^Z0``6>DD'WM[*MAI?PP`*H$X2`E_``2)+R0`GD`0`(KH>-MC
M?\7(_TL8`$'H``"C+X3_GD"T!YU_0/__2P``?X"AQO]+&`!!Z```F>@"`,`X
M``"@.'W'_TL8`$'H>!MD?,#__TL``'^`><;_2Q@`0>@0`#WI_O^B/*3@I3@`
M`(GH"<3_2Q@`0>@0`#WI```IZ0P`*8%``"IU:/Z"00``?X!!QO]+&`!!Z!``
M/>D``(GHC<3_2Q@`0>A(_O]+.>O_2WD;?'P``'^`T`""017&_TL8`$'H$``]
MZ7CCA7\``(GHJ</_2Q@`0>AXXX-_[</_2Q@`0>@``'^`Z<7_2Q@`0>AX&WU\
M``!_@-G%_TL8`$'H_O^"/`$`H#BKX(0XA<3_2Q@`0>C^_Z(\P."E.'@;9'QX
MZZ-_5</_2Q@`0>@``'^`H<7_2Q@`0>@``"`YN0`CF?[_8CS>WF,X7>3_2P``
M`&```*,OT)%B^$P`GD````!@R)%BZ+'R_TL```!@``"C+]"18O@P`)Y`_O]B
M/,;@8S@EQ/]+&`!!Z$G%_TL8`$'H````8,B10ND0`#WI``"JZ*3]_TL```!@
MT)%BZ,`!@#C%QO]+&`!!Z!$`@R]X&V9\+`">00$`(SD!`(DK(`"=0!`0/ND8
M$+[H_O]B/.?@8S@``(GHP</_2Q@`0>B@`"$X?`$`2``````````!@`@```(`
M3#RH)$(XI@((?/#_P?OX_^'[>!M^?!```?B1_R'X)>W_2^'L_TMX&W]\0?#_
M2P``HR]0`)Y!``"^+T@`GD$``#Z)``")+SP`GD'^_X(\>/OC?\G?A#B=P_]+
M&`!!Z``8OW\@`)Y`<``A.'CSPW\0``'H\/_!Z_C_X>NF`PA\1.;_2W``(3@0
M`0!(``````````&``@``````8````&````!@````8`(`3#P`)$(XI@((?/__
M(CT@?"GI^/_A^___XC\@?/\[__^I+Q```?C1_R'X-`">00```&````!@````
M8```0F"F`RE]>$LL?1@`0?@A!(!.&`!!Z/G_/^G__ZDOY/^>0#``(3@0``'H
M^/_AZZ8#"'P@`(!.F/]A^J#_@?JH_Z'ZL/_!^KC_X?K`_P'[R/\A^]#_0?O8
M_V'[X/^!^^C_H?OP_\'[^/_A^Q```?@@`(!.F/]AZJ#_@>JH_Z'JL/_!ZKC_
MX>K`_P'KR/\AZ]#_0>O8_V'KX/^!ZQ```>CH_Z'KI@,(?/#_P>OX_^'K(`"`
M3O#_P>L0``'H^/_AZZ8#"'P@`(!.````8/"@`0``````I@((?`4`GT*F`FA]
M\/]+Z*8#"'Q08(M]%%IB?=#_##@``(OI@O``>*8#B7T(`&OI(`2`3@```&#(
M__]+Q/__2\#__TN\__]+N/__2[3__TNP__]+K/__2ZC__TND__]+H/__2YS_
M_TN8__]+E/__2Y#__TN,__]+B/__2X3__TN`__]+?/__2WC__TMT__]+</__
M2VS__TMH__]+9/__2V#__TM<__]+6/__2U3__TM0__]+3/__2TC__TM$__]+
M0/__2SS__TLX__]+-/__2S#__TLL__]+*/__2R3__TL@__]+'/__2QC__TL4
M__]+$/__2PS__TL(__]+!/__2P#__TO\_O]+^/[_2_3^_TOP_O]+[/[_2^C^
M_TOD_O]+X/[_2]S^_TO8_O]+`@!,/,0A0CBF`@A\$``!^.'_(?CYQ_]+````
M8"``(3@0``'HI@,(?"``@$YP97)L>'-I+F,`7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("```"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN
M84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5`!E>&4`+W!R;V,O)6DO)7,`
M4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%
M4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%2
M7T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!0
M05)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!0
M05)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`3$1?3$E"4D%265]0051(`%-9
M4U1%30`E,#)X`'!A<BT`)7,E<R5S)7,`)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@!P87)L`"YP
M87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE
M=25S`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`05)'
M5@`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`T,0!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`"UE`"TM`%5315(`55-%4DY!344`5$5-4$1)4@!435``+W1M<`!E=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P[
M"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A
M<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M
M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N
M86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M
M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L
M;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF
M:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P
M87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-
M4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@
M(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S
M971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O
M<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![
M?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H
M7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O
M9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E
M="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F
M<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@
M)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE
M('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N
M<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP
M;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@
M?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T
M('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@
M7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(
M+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@
M)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U
M:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM
M>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D
M9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH
M6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L
M("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\
M<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R
M8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@
M/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@
M>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D
M8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS
M92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^
M("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F
M+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE
M*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY
M("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\
M(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2![
M"FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0[
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y
M*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL
M96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F
M:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*
M?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M
M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G
M/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D
M(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.
M0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL
M93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?
M;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N
M86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*
M?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL
M97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@
M)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D55
M4T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B
M;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A
M)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F
M('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R
M"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P
M87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E
M<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]21553
M17T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA
M=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP
M72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H
M)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G
M*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G
M*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@
M/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L
M;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF
M("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B
M6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G
M*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@
M)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0
M)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D
M9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'
M5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D
M<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H
M)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G
M)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A
M;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD
M;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,[
M"B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D
M+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P
M87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R
M(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP
M,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?
M5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@
M/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A
M9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD
M=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC
M(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@
M(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA
M9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@
M+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*
M)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D[
M"G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.
M+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[
M)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L
M=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E
M>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@
M>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2![
M"FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F
M:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C
M72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]
M"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H
M;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B
M)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO
M="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q
M*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL
M92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L
M("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I
M;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q
M*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^
M<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U
M=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I
M.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A
M)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@
M>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S
M=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N
M(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D
M<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS
M.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE
M;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB
M:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M
M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN
M(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H
M*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A
M.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0
M?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@
M8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG
M.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*
M;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?
M5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q
M*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*
M979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R
M.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S
M="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!]
M.PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L
M87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T
M96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]
M"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-
M4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0
M("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M
M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED
M.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^
M.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R
M;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P
M=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M
M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<[
M"GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T
M:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@
M*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS
M>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B
M*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*
M)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@
M;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P
M<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N
M9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^
M:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*
M)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\[
M"GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D
M92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N
M;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA
M;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C
M86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT
M("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP
M;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L
M;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA
M;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I
M('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%
M3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%
M35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE
M?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N
M9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I
M;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@
M*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O
M;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF
M;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!
M4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]4
M14U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI
M<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B
M<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM0
M05)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI
M+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F
M:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<
M;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`
M24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q
M=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E
M>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA
M:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A
M<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N
M)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE
M(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O
M9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF
M("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/
M4CL*,3L*7U]%3D1?7PH`````%``````````!>E(`!'A!`1L,`0``````%```
M`!P```#<?___Q`0`````````````%````#0```!4O___+`$```!!"4$`1`9!
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````/__________``````````#_
M_________P`````````````````````!``````````$``````````0``````
M``#A`@````````\`````````:@,````````,`````````$@<````````#0``
M```````\70```````/7^_V\`````Z`$````````%`````````'@.````````
M!@````````"H`@````````H`````````N04````````+`````````!@`````
M````%0````````````````````,`````````"/T!```````"`````````+@%
M````````%``````````'`````````!<`````````D!8```````````!P````
M`"A<`````````P``<`````````````````<`````````.!0````````(````
M`````%@"````````"0`````````8`````````!@```````````````````#[
M__]O``````$```@`````^?__;P`````+````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````_____P````!(8````````)5=````
M``````````````!V7@```````&]>````````/&````````",7@```````$1@
M```````````````````N8````````#-@``````````````````!-8```````
M`$=#0SH@*$%L<&EN92`V+C0N,"D@-BXT+C```"YS:'-T<G1A8@`N:6YT97)P
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N8W1O<G,`
M+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT
M````````````````````````````````````````````````````````````
M````````````````````````````````"P````$````"`````````,@!````
M````R`$````````>`````````````````````0```````````````````!,`
M``#V__]O`@````````#H`0```````.@!````````O``````````#````````
M``@````````````````````=````"P````(`````````J`(```````"H`@``
M`````-`+````````!````!T````(`````````!@`````````)0````,````"
M`````````'@.````````>`X```````"Y!0```````````````````0``````
M`````````````"T````$`````@`````````X%````````#@4````````6`(`
M```````#``````````@`````````&``````````W````!````$(`````````
MD!8```````"0%@```````+@%`````````P```!`````(`````````!@`````
M````00````$````&`````````$@<````````2!P````````T````````````
M````````!````````````````````$<````!````!@````````"`'```````
M`(`<````````O$```````````````````"````````````````````!-````
M`0````8`````````/%T````````\70```````"P````````````````````$
M````````````````````4P````$````"`````````&A=````````:%T`````
M```9/P``````````````````"````````````````````%L````!`````@``
M``````"$G````````(2<````````3`````````````````````0`````````
M``````````!E`````0````,`````````(/L!```````@^P```````!``````
M```````````````(````````````````````;`````$````#`````````##[
M`0``````,/L````````0````````````````````"```````````````````
M`',````!`````P````````!`^P$``````$#[````````"```````````````
M``````@```````````````````!X````!@````,`````````2/L!``````!(
M^P```````,`!````````!``````````(`````````!``````````/`````@`
M```#``````````C]`0``````"/T```````#X`0``````````````````"```
M```````(`````````($````!`````P``````````_P$```````#_````````
M>``````````````````````!````````"`````````"&`````0````,`````
M```````"``````````$``````'@````````````````````(````````````
M````````C`````@````#`````````'@``@``````>``!``````!H$```````
M````````````"````````````````````)$````!````,```````````````
M`````'@``0``````&@````````````````````$``````````0`````````!
M`````P````````````````````````"2``$``````)H`````````````````
2```!````````````````````
